@@ -6,7 +6,7 @@ package SQL::Bibliosoph; {
 	use SQL::Bibliosoph::Query;
 	use SQL::Bibliosoph::CatalogFile;
 
-    our $VERSION = "2.01";
+    our $VERSION = "2.02";
 
 
     has 'dbh'       => ( is => 'ro', isa => 'DBI::db',  required=> 1);
@@ -17,7 +17,7 @@ package SQL::Bibliosoph; {
 
     has 'delayed'   => ( is => 'ro', isa => 'Bool', default=> 0);
     has 'debug'     => ( is => 'ro', isa => 'Bool', default=> 0);
-    has 'benchmark' => ( is => 'ro', isa => 'Bool', default=> 0);
+    has 'benchmark' => ( is => 'ro', isa => 'Num', default=> 0);
 
     has 'queries'   => ( is => 'rw', default=> sub { return {}; } );
 
@@ -294,6 +294,7 @@ package SQL::Bibliosoph; {
                         st      => $st, 
                         name    => $name,
                         delayed => $self->delayed(),
+                        benchmark=> $self->benchmark(),
             };
             #print STDERR " Query for ".Dumper($args);            
 
@@ -327,7 +328,8 @@ SQL::Bibliosoph - A SQL Statements Library
 	my $bs = SQL::Biblioshoph->new(
 			dsn		 => $database_handle,
 			catalog  => [ qw(users products <billing) ],
-    #       benchmark=> 1,      # to enable statement benchmarking and debug
+    #       benchmark=> 0.5,      # to enable statement benchmarking and debug 
+    #                               0.5 = log queries that takes more than half second
     #       debug    => 1,      # to enable debug to STDERR
 	);
 
@@ -441,7 +443,8 @@ Do not prepare all the statements at startup. They will be prepared individualy,
 =head3 benchmark
 
 Use this to enable Query profilling. The elapsed time (in miliseconds) will be printed
-to STDERR after each query execution.
+to STDERR after each query execution, if the time is bigger that `benchmark` (must be 
+given in SECONDS, can be a floating point number)
 
 =head3 debug
 
